import type { EasingFunctionDescription } from '@yandex/ymaps3-types/common/types';
import type { CustomVuefyOptions } from '@yandex/ymaps3-types/modules/vuefy';
import './index.css';
/**
 * YMapZoomControl props
 */
type YMapZoomControlProps = {
    /** Easing function for map location animation */
    easing?: EasingFunctionDescription;
    /** Map location animate duration */
    duration?: number;
};
/**
 * Display zoom control on a map.
 *
 * @example
 * ```javascript
 * const controls = new YMapControls({position: 'right'});
 * const zoomControl = new YMapZoomControl();
 * controls.addChild(zoomControl);
 * map.addChild(controls);
 * ```
 */
declare class YMapZoomControl extends ymaps3.YMapComplexEntity<YMapZoomControlProps> {
    static [ymaps3.optionsKeyVuefy]: CustomVuefyOptions<YMapZoomControl>;
    static defaultProps: Readonly<{
        duration: 200;
    }>;
    private _control;
    private _zoom;
    protected _onAttach(): void;
    protected _onUpdate(props: YMapZoomControlProps): void;
    protected _onDetach(): void;
}
export { YMapZoomControl, YMapZoomControlProps };
